aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/screen.h
diff options
context:
space:
mode:
authorMax Horn2011-04-14 14:12:27 +0200
committerMax Horn2011-04-14 14:12:35 +0200
commit84184aabc00251374a181fe296487619afa779ed (patch)
tree6e635dcaf2300d979e6ad1be9a5e9e0ec653df4a /engines/sword2/screen.h
parent64c4e65201ca3097cc25b295359683eafaf25b07 (diff)
downloadscummvm-rg350-84184aabc00251374a181fe296487619afa779ed.tar.gz
scummvm-rg350-84184aabc00251374a181fe296487619afa779ed.tar.bz2
scummvm-rg350-84184aabc00251374a181fe296487619afa779ed.zip
ALL: colour -> color
Diffstat (limited to 'engines/sword2/screen.h')
-rw-r--r--engines/sword2/screen.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sword2/screen.h b/engines/sword2/screen.h
index 46eb53d0db..9ef4f28049 100644
--- a/engines/sword2/screen.h
+++ b/engines/sword2/screen.h
@@ -172,7 +172,7 @@ struct SpriteInfo {
uint16 type; // mask containing 'RDSPR_' bits specifying compression type, flip, transparency, etc
uint16 blend; // holds the blending values.
byte *data; // pointer to the sprite data
- byte *colourTable; // pointer to 16-byte colour table, only applicable to 16-col compression type
+ byte *colorTable; // pointer to 16-byte color table, only applicable to 16-col compression type
bool isText; // It is a engine-generated sprite containing text
};
@@ -442,8 +442,8 @@ public:
void buildDisplay();
- void plotPoint(int x, int y, uint8 colour);
- void drawLine(int x0, int y0, int x1, int y1, uint8 colour);
+ void plotPoint(int x, int y, uint8 color);
+ void drawLine(int x0, int y0, int x1, int y1, uint8 color);
void rollCredits();
void splashScreen();